import deltalake
from pyspark.sql import SparkSession, types
from delta import configure_spark_with_delta_pip
from tempfile import TemporaryDirectory

builder = SparkSession.builder.appName("MyApp") \
    .config("spark.sql.extensions", "io.delta.sql.DeltaSparkSessionExtension") \
    .config("spark.sql.catalog.spark_catalog", "org.apache.spark.sql.delta.catalog.DeltaCatalog")

spark = configure_spark_with_delta_pip(builder).getOrCreate()

with TemporaryDirectory() as temp_path:
    test_df0 = spark.createDataFrame(
        [{"nested_column": {"sub_column0": "row0"}}],
        schema=types.StructType(
            [
                types.StructField(
                    "nested_column", types.StructType([types.StructField("sub_column0", types.StringType())])
                ),
            ]
        ),
    )
    test_df0.write.format("delta").mode("append").save(temp_path)
    test_df1 = spark.createDataFrame(
        [{"nested_column": {"sub_column1": "row1"}}],
        schema=types.StructType(
            [
                types.StructField(
                    "nested_column", types.StructType([types.StructField("sub_column1", types.StringType())])
                ),
            ]
        ),
    )
    test_df1.write.format("delta").mode("append").option("mergeSchema", "true").save(temp_path)

    pyarrow_table = deltalake.DeltaTable(temp_path).to_pyarrow_table()
